#
# spec file for package python-jupyter_console
#
# Copyright (c) 2020 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-jupyter_console
Version:        6.1.0
Release:        bp153.1.19
Summary:        Jupyter terminal console
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/jupyter_console
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter_console/jupyter_console-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module jupyter-client}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module prompt_toolkit >= 2}
BuildRequires:  %{python_module pyzmq}
# /SECTION
Requires:       python-jupyter-client
Requires:       python-ipykernel
Requires:       python-ipython
Requires:       python-prompt_toolkit >= 2
Requires:       python-pyzmq
Requires:       jupyter-jupyter_console = %{version}
BuildArch:      noarch

%python_subpackages

%description
A terminal-based console frontend for Jupter kernels.
This code is based on the single-process IPython terminal.

This package provides the python components.

%package     -n jupyter-jupyter_console
Summary:        Jupyter terminal console
Requires:       python3-jupyter_console = %{version}
Provides:       jupyter-jupyter_console-doc = %{version}
Obsoletes:      jupyter-jupyter_console-doc < %{version}

%description -n jupyter-jupyter_console
A terminal-based console frontend for Jupter kernels.
This code is based on the single-process IPython terminal.

This package provides the jupyter components.

%prep
%setup -q -n jupyter_console-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand nosetests-%{$python_bin_suffix} jupyter_console

%files %{python_files}
%doc CONTRIBUTING.md README.md
%license COPYING.md 
%{python_sitelib}/*

%files -n jupyter-jupyter_console
%license COPYING.md

%changelog
* Tue Jan 28 2020 Todd R <toddrme2178@gmail.com>
- Update to 6.1.0
  * switch bumpversion to nbformat-style
  * Remove Python 2 compatibility code.
  * Add support for prompt-toolkit v3
  * removed extra lines from the banner
- Drop documentation.
  These are mostly a relic of when the tests needed to be in a
  separate package, and since the docs are no longer versioned
  upstream keeping them synced with the main package is difficult.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- jupyter_client renamed to jupyter-client
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Enable tests
* Fri May 17 2019 Todd R <toddrme2178@gmail.com>
- Split jupyter components into own subpackage.
* Tue Oct 16 2018 Todd R <toddrme2178@gmail.com>
- Update to version 6.0.0
  * Drop support for python 2
  * Upgrade to prompt_toolkit 2.x
- Don't build for python2 anymore since it isn't supported.
* Sun Oct  7 2018 Todd R <toddrme2178@gmail.com>
- Use upstream builds of doc files.
- Merge doc subpackage and tests into main spec file.
- Use %%license tag
- Fix prompt_toolkit dependency.
* Sun Jul 22 2018 toddrme2178@gmail.com
- Not compatible with prompt_toolkit 2.x
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 5.2.0
  * When using a kernel that the console did not start, exiting with Ctrl-D now
    leaves it running.
  * Added Ctrl-\\ shortcut to quit the console.
  * Input prompt numbers are now updated when another frontend has executed
    code in the same kernel.
  * Fix setting next input with newer versions of prompt_toolkit.
  * Ensure history entries are unicode, not bytes, on Python 2.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Mar 31 2017 toddrme2178@gmail.com
- Updaste to 5.1
  * New ``ZMQTerminalInteractiveShell.true_color`` config option to use 24-bit
  colour.
  * New ``ZMQTerminalInteractiveShell.confirm_exit`` config option to turn off
  asking 'are you sure' on exit.
  * New ``--simple-prompt`` flag to explicitly use the fallback mode without
  prompt_toolkit.
  * Fixed executing an empty input.
  * Fixed formatting for code and outputs from other frontends executing code.
  * Avoid using functions which will be removed in IPython 6.
- Updaste to 5.0.0
  + Interactive Shell architecture
  * disinherit shell class from IPython Interactive Shell `#68 <https://github.com/jupyter/jupyter_console/pull/68>`_
    This separates jupyter_console's ZMQTerminalInteractiveShell from IPython's TerminalInteractiveShell and InteractiveShell classes.
  * update SIGINT handler to not use the old interactive API shell `#80 <https://github.com/jupyter/jupyter_console/pull/80>`_
  + Image Handling improvement
  * use PIL as default image handler `#79 <https://github.com/jupyter/jupyter_console/pull/79>`_
  * better indication of whether image data was handled `#77 <https://github.com/jupyter/jupyter_console/pull/77>`_
  + Prompts improvement
  * use prompt_toolkit 1.0 `#74 <https://github.com/jupyter/jupyter_console/pull/74>`_
  * don't use prompt_manager `#75 <https://github.com/jupyter/jupyter_console/pull/75>`_
  * remove ``colors_force`` flag that have no effects: `#88 <https://github.com/jupyter/jupyter_console/pull/88>`_
- Updaste to 4.1.1
  * fix for readline history
  * don't confuse sys.path with virtualenvs
* Thu Feb 18 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
  * Split documentation into subpackage
- update to version 4.1.0:
  * readline/completion fixes
  * use is_complete messages to determine if input is complete
    (important for non-Python kernels)
  * fix: 4.0 was looking for jupyter_console_config in IPython config
    directories, not Jupyter
* Mon Oct 12 2015 toddrme2178@gmail.com
- Update to 4.0.3
  * fix jupyter console --generate-config
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Wed Sep 16 2015 toddrme2178@gmail.com
- Update to 4.0.2
  * fix `jupyter console --generate-config`
  * add long_description
  * fix setuptools entrypoint
- Update to 4.0.1
  * entrypoints only when setuptools invoked
  * bug fix
  * suggestion for windows users
  * Fix printing errors when execute_reply and error messages come
  * Try installing IPython from Github on RTD
  * Try installing on RTD with --pre to get IPython 4
  * Add requirements file for RTD
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
